@@ -6,12 +6,13 @@ from zope.i18nmessageid import MessageFactory
 from Products.Archetypes.public import StringField
 
 from Products.ATContentTypes.interfaces.news import IATNewsItem
+from Products.ATContentTypes.interface import IATFolder
 from Products.Archetypes.atapi import SelectionWidget
 
 from archetypes.schemaextender.interfaces import ISchemaExtender, IBrowserLayerAwareExtender 
 from archetypes.schemaextender.field import ExtensionField
 
-from medialog.newsitemview.interfaces import INewsitemObject
+from medialog.newsitemview.interfaces import INewsitemObject, IFolderObject
 
 from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm
 from medialog.newsitemview.vocabulary import ImageSizeVocabulary 
@@ -47,6 +48,37 @@ class ContentTypeExtender(object):
                 ),
             ),
         ]
+
+    def __init__(self, context):
+    	self.context = context
+
+    def getFields(self):
+        return self._fields
+
+#    def __init__(self, contentType):
+#        pass
+
+class FolderTypeExtender(object):
+    """Adapter that adds custom data used for image size."""
+    adapts(IATFolder)
+    implements(ISchemaExtender, IBrowserLayerAwareExtender)
+    layer = IFolderObject
+    _fields = [
+        _StringExtensionField("folderimagesize",
+            schemata = "settings",
+            enforceVocabulary=True,
+            vocabulary = ImageSizeVocabulary(),
+            default="preview",
+            interfaces = (INewsitemObject,),
+            widget = SelectionWidget(
+                label = _(u"label_folderimagesize",
+                    default=u"Size for image in summary view"),
+                description = _(u"help_folderimagesize",
+                    default=u"Choose Size"),
+                ),
+            ),
+        ]
+
         
     def __init__(self, context):
     	self.context = context
